==> cucumber-groovy-1.2.3-sources.jar: cucumber/api/groovy/RU.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class RU {

    public static void А(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void А(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Дано(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Дано(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Допустим(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Допустим(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Если(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Если(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void И(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void И(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Ктомуже(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Ктомуже(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Когда(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Когда(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Но(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Но(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Пусть(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Пусть(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Также(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Также(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void То(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void То(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Тогда(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Тогда(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-2.0.1-sources.jar: cucumber/api/groovy/RU.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class RU {

    public static void Допустим(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Допустим(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Дано(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Дано(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Пусть(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Пусть(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Если(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Если(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Когда(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Когда(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void То(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void То(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Затем(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Затем(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Тогда(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Тогда(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void И(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void И(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Ктомуже(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Ктомуже(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Также(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Также(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Но(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void Но(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void А(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, 0, body);
    }

    public static void А(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.getInstance().addStepDefinition(regexp, timeoutMillis, body);
    }

}
